@@ -4,7 +4,9 @@ import sys
 
 from smac.utils import dependencies
 
-__version__ = '1.0.0'
+__copyright__ = "Copyright 2021, AutoML.org Freiburg-Hannover"
+__license__ = "3-clause BSD"
+__version__ = '1.1.1'
 __author__ = 'Marius Lindauer, Katharina Eggensperger, Matthias Feurer, André Biedenkapp, ' \
              'Difan Deng, Carolin Benjamins, René Sass ' \
              'and Frank Hutter'
@@ -16,12 +18,10 @@ with open(os.path.join(os.path.dirname(__file__), 'requirements.txt')) as fh:
 with open(os.path.join(os.path.dirname(__file__), 'extras_require.json')) as fh:
     extras_require = json.load(fh)
 
-extras_installed = set()
+extras_installed = set()  # type: set
 for name, requirements in extras_require.items():
     if name in ['documentation', 'test']:
         continue
-    if dependencies.are_valid_packages(requirements):
-        extras_installed.add(name)
 
 if sys.version_info < (3, 7, 0):
     raise ValueError("SMAC requires Python 3.7.0 or newer.")
