@@ -4,7 +4,6 @@ from ConfigSpace import Configuration
 
 from smac.initial_design.initial_design import InitialDesign
 
-
 __author__ = "Katharina Eggensperger"
 __copyright__ = "Copyright 2016, ML4AAD"
 __license__ = "3-clause BSD"
@@ -22,7 +21,7 @@ class RandomConfigurations(InitialDesign):
             Initial incumbent configuration
         """
 
-        configs = self.scenario.cs.sample_configuration(size=self.init_budget)
+        configs = self.cs.sample_configuration(size=self.init_budget)
         if self.init_budget == 1:
             configs = [configs]
         for config in configs:
