@@ -1,6 +1,6 @@
 import typing
 
-import sobol_seq
+from scipy.stats.qmc import Sobol
 
 from ConfigSpace.configuration_space import Configuration
 from ConfigSpace.hyperparameters import Constant
@@ -13,7 +13,9 @@ __license__ = "3-clause BSD"
 
 
 class SobolDesign(InitialDesign):
-    """ Sobol sequence design
+    """ Sobol sequence design with a scrambled Sobol sequence.
+
+    See https://scipy.github.io/devdocs/reference/generated/scipy.stats.qmc.Sobol.html for further information
 
     Attributes
     ----------
@@ -39,7 +41,9 @@ class SobolDesign(InitialDesign):
             if isinstance(p, Constant):
                 constants += 1
 
-        sobol = sobol_seq.i4_sobol_generate(len(params) - constants, self.init_budget)
+        dim = len(params) - constants
+        sobol_gen = Sobol(d=dim, scramble=True, seed=self.rng.randint(low=0, high=10000000))
+        sobol = sobol_gen.random(self.init_budget)
 
         return self._transform_continuous_designs(design=sobol,
                                                   origin='Sobol',
