@@ -28,7 +28,6 @@ from smac.tae.base import BaseRunner
 from smac.utils.io.traj_logging import TrajLogger
 from smac.utils.validate import Validator
 
-
 __author__ = "Aaron Klein, Marius Lindauer, Matthias Feurer"
 __copyright__ = "Copyright 2015, ML4AAD"
 __license__ = "3-clause BSD"
@@ -302,7 +301,7 @@ class SMBO(object):
                 if self.stats.is_budget_exhausted():
                     self.logger.debug("Exhausted configuration budget")
                 else:
-                    self.logger.debug("Shutting down because a configuration returned status STOP")
+                    self.logger.debug("Shutting down because a configuration or callback returned status STOP")
 
                 # The budget can be exhausted  for 2 reasons: number of ta runs or
                 # time. If the number of ta runs is reached, but there is still budget,
@@ -472,7 +471,7 @@ class SMBO(object):
             self._stop = True
             return
 
-        if self.scenario.abort_on_first_run_crash :  # type: ignore[attr-defined] # noqa F821
+        if self.scenario.abort_on_first_run_crash:  # type: ignore[attr-defined] # noqa F821
             if self.stats.finished_ta_runs == 1 and result.status == StatusType.CRASHED:
                 raise FirstRunCrashedException(
                     "First run crashed, abort. Please check your setup -- we assume that your default "
@@ -490,7 +489,12 @@ class SMBO(object):
         )
 
         for callback in self._callbacks['_incorporate_run_results']:
-            callback(smbo=self, run_info=run_info, result=result, time_left=time_left)
+            response = callback(smbo=self, run_info=run_info, result=result, time_left=time_left)
+            # If a callback returns False, the optimization loop should be interrupted
+            # the other callbacks are still being called
+            if response is False:
+                self.logger.debug("An IncorporateRunResultCallback returned False, requesting abort.")
+                self._stop = True
 
         if self.scenario.save_results_instantly:  # type: ignore[attr-defined] # noqa F821
             self.save()
