@@ -4,20 +4,15 @@ import re
 import typing
 from distutils.version import LooseVersion
 
+__copyright__ = "Copyright 2021, AutoML.org Freiburg-Hannover"
+__license__ = "3-clause BSD"
+
+
 SUBPATTERN = r'((?P<operation%d>==|>=|>|<)(?P<version%d>(\d+)?(\.[a-zA-Z0-9]+)?(\.\d+)?))'
 RE_PATTERN = re.compile(
     r'^(?P<name>[\w\-]+)%s?(,%s)?$' % (SUBPATTERN % (1, 1), SUBPATTERN % (2, 2)))
 
 
-def are_valid_packages(packages: typing.Union[typing.List[str], str]) -> bool:
-    try:
-        verify_packages(packages)
-    except (MissingPackageError, IncorrectPackageVersionError):
-        return False
-    else:
-        return True
-
-
 def verify_packages(packages: typing.Union[typing.List[str], str]) -> None:
     if not packages:
         return
