@@ -12,6 +12,9 @@ from smac.scenario.scenario import Scenario
 from smac.facade.smac_ac_facade import SMAC4AC
 from smac.stats.stats import Stats
 
+__copyright__ = "Copyright 2021, AutoML.org Freiburg-Hannover"
+__license__ = "3-clause BSD"
+
 
 class TestSMACCLI(unittest.TestCase):
 
@@ -42,11 +45,11 @@ class TestSMACCLI(unittest.TestCase):
         Testing basic restore functionality.
         """
         # Run for 5 algo-calls
-        testargs = ["python", "scripts/smac", "--scenario_file",
+        testargs = ["python", "scripts/smac.py", "--scenario_file",
                     self.scenario_one, "--verbose", "DEBUG"]
         self.smaccli.main_cli(testargs[2:])
         # Increase limit and run for 10 (so 5 more) by using restore_state
-        testargs = ["python", "scripts/smac", "--restore_state",
+        testargs = ["python", "scripts/smac.py", "--restore_state",
                     self.output_one, "--scenario_file",
                     self.scenario_two, "--verbose", "DEBUG"]
         self.smaccli.main_cli(testargs[2:])
@@ -55,7 +58,7 @@ class TestSMACCLI(unittest.TestCase):
         """
         Testing error if dir is missing.
         """
-        testargs = ["python", "scripts/smac", "--restore_state",
+        testargs = ["python", "scripts/smac.py", "--restore_state",
                     "nonsense_test_dir", "--scenario_file",
                     self.scenario_two, "--verbose", "DEBUG"]
         self.assertRaises(FileNotFoundError, lambda: self.smaccli.main_cli(testargs[2:]))
@@ -69,7 +72,7 @@ class TestSMACCLI(unittest.TestCase):
         scen = Scenario({'run_obj': 'quality', 'cs': cs})
         stats = Stats(scen)
         # Recorded runs but no incumbent.
-        stats.ta_runs = 10
+        stats.submitted_ta_runs = 10
         smac = SMAC4AC(scen, stats=stats, rng=np.random.RandomState(42))
         self.output_dirs.append(scen.output_dir)
         self.assertRaises(ValueError, smac.optimize)
@@ -83,11 +86,11 @@ class TestSMACCLI(unittest.TestCase):
         Testing possible error using same dir for restore
         """
         # Run for 5 algo-calls
-        testargs = ["python", "scripts/smac", "--scenario",
+        testargs = ["python", "scripts/smac.py", "--scenario",
                     self.scenario_one, "--verbose", "DEBUG"]
         self.smaccli.main_cli(testargs[2:])
         # Increase limit and run for 10 (so 5 more) by using restore_state
-        testargs = ["python", "scripts/smac", "--restore_state",
+        testargs = ["python", "scripts/smac.py", "--restore_state",
                     self.output_one, "--scenario",
                     self.scenario_two, "--verbose", "DEBUG"]
         # TODO: fix
