@@ -1,8 +1,3 @@
-'''
-Created on Dec 15, 2015
-
-@author: Aaron Klein
-'''
 import unittest
 import unittest.mock
 import os
@@ -20,6 +15,9 @@ from ConfigSpace.hyperparameters import CategoricalHyperparameter, \
     UniformFloatHyperparameter, UniformIntegerHyperparameter
 from smac.utils import test_helpers
 
+__copyright__ = "Copyright 2021, AutoML.org Freiburg-Hannover"
+__license__ = "3-clause BSD"
+
 
 class ConfigurationMock(object):
     def __init__(self, value=None):
