@@ -1,8 +1,3 @@
-'''
-Created on Nov 15, 2018
-
-@author: biedenk
-'''
 import os
 import unittest
 import shlex
@@ -10,10 +5,13 @@ import shlex
 from smac.configspace import ConfigurationSpace
 from smac.tae.execute_ta_run_hydra import ExecuteTARunHydra
 from smac.tae.execute_ta_run_aclib import ExecuteTARunAClib
-from smac.tae.execute_ta_run import StatusType
+from smac.tae import StatusType
 from smac.scenario.scenario import Scenario
 from smac.stats.stats import Stats
 
+__copyright__ = "Copyright 2021, AutoML.org Freiburg-Hannover"
+__license__ = "3-clause BSD"
+
 
 class TaeHydra(unittest.TestCase):
 
