@@ -1,8 +1,3 @@
-'''
-Created on Apr 25, 2015
-
-@author: Andre Biedenkapp
-'''
 import tempfile
 import logging
 import json
@@ -19,6 +14,9 @@ from smac.configspace import ConfigurationSpace,\
 from smac.scenario.scenario import Scenario
 from smac.stats.stats import Stats
 
+__copyright__ = "Copyright 2021, AutoML.org Freiburg-Hannover"
+__license__ = "3-clause BSD"
+
 
 class TrajLoggerTest(unittest.TestCase):
 
